#########################################################
### REPLICATION CODE                                  ### 
### Sven-Oliver Proksch and Jonathan Slapin           ###
### "Institutional Foundations of Legislative Speech" ###
### American Journal of Political Science             ###
### 56(3): 520-537, 2012 						      ###
#########################################################


# Clear workspace
rm(list = ls(all = TRUE))

# Load libraries
library(Zelig)
library(memisc)
library(pscl)

# Change working directory here
setwd("")

# Load data
load("legspeechdata.Rdata")

## The list object "legspeechdata" contains the following data:
## (1)  consfinal: UK Conservatives, MP-level data, leader/backbencher status (1997-2005)
## (2)  conspeeches: UK Conservatives, MP-level data, speech counts (1997-2005)
## (3)  labourfinal: UK Labour, MP-level data, leader/backbencher status (1997-2005)
## (4)  labourfinalwhips: UK Labour, MP-level data, leader (only whips)/backbencher status (1997-2005)
## (5)  labourfinalgov: UK Labour, MP-level data, leader (with cabinet)/backbencher status (1997-2005)
## (6)  labspeeches: UK Labour, MP-level data, speech counts (1997-2005)
## (7)  BundestagSpeeches: Germany, MP-level data, monthly leadership status, 
##      monthly membership status, monthly number of speeches, monthly speeches,
##	    1976-1998
## (8)  ukMPdata: MP-level speech data, 2001-2005 with ideological distance 
## (9)  gerMPdata: MP-level speech data, 2005-2009 with ideological distance 
## (10) budgetdebates: MP-level speech data, budget debates (GER:2010,UK:2011)
## (11) GERattendance: MP-level proportion of excused parliamentary sessions (2005-2009)

# Load auxiliary functions
source("UKauxfunctions.R")
source("GERauxfunctions.R")


#########################
#########################
# Party-Level Analysis  #
#########################
#########################

###############################################
## Figure 2A: UNITED KINGDOM (House of Commons)
###############################################

# Conservatives
out.cons<-leaderproportionsUK(leadpositions=2,data=legspeechdata$consfinal,speeches=legspeechdata$conspeeches)
out.cons

# Labour
out.lab<-leaderproportionsUK(leadpositions=2,data=legspeechdata$labourfinal,speeches=legspeechdata$labspeeches)
out.lab

# Make plot
par(mfrow=(c(2,1)),oma=c(0,0,0,0))
plotleadertermUK(data= out.lab,plotleg=FALSE,mytitle="Labour Party",xlabtitle="Proportion of leader MP speeches")
plotleadertermUK(data= out.cons,plotleg=FALSE,mytitle="Conservative Party",xlabtitle="Proportion of leader MP speeches")


#################################
## Figure 2B: GERMANY (Bundestag)
#################################

# CDU/CSU
leader8cdu<-leaderproportionsGER(legperiod=8,leadpositions= c(2,3,4,5,9,10,11),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
leader9cdu<-leaderproportionsGER(legperiod=9,leadpositions= c(2,3,4,5,9,10,11),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
leader9acdu<-leaderproportionsGER(legperiod="9a",leadpositions= c(2,3,4,5,9,10,11),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
leader9bcdu<-leaderproportionsGER(legperiod="9b",leadpositions= c(2,3,4,5,9,10,11),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
leader10cdu<-leaderproportionsGER(legperiod=10,leadpositions= c(2,3,4,5,9,10,11),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
leader11cdu<-leaderproportionsGER(legperiod=11,leadpositions= c(2,3,4,5,9,10,11),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"),nounif=TRUE)
leader12cdu<-leaderproportionsGER(legperiod=12,leadpositions= c(2,3,4,5,9,10,11),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
leader13cdu<-leaderproportionsGER(legperiod=13,leadpositions= c(2,3,4,5,9,10,11),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
leaderALLcdu<-rbind(leader8cdu,leader9cdu,leader10cdu,leader11cdu,leader12cdu,leader13cdu)
leaderALLcdu

# SPD
leader8spd<-leaderproportionsGER(legperiod=8,leadpositions= c(2,3,4,5,9,10,11),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
leader9spd<-leaderproportionsGER(legperiod=9,leadpositions= c(2,3,4,5,9,10,11),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
leader9aspd<-leaderproportionsGER(legperiod="9a",leadpositions= c(2,3,4,5,9,10,11),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
leader9bspd<-leaderproportionsGER(legperiod="9b",leadpositions= c(2,3,4,5,9,10,11),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
leader10spd<-leaderproportionsGER(legperiod=10,leadpositions= c(2,3,4,5,9,10,11),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
leader11spd<-leaderproportionsGER(legperiod=11,leadpositions= c(2,3,4,5,9,10,11),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD",nounif=TRUE)
leader12spd<-leaderproportionsGER(legperiod=12,leadpositions= c(2,3,4,5,9,10,11),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
leader13spd<-leaderproportionsGER(legperiod=13,leadpositions= c(2,3,4,5,9,10,11),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
leaderALLspd<-rbind(leader8spd,leader9spd,leader10spd,leader11spd,leader12spd,leader13spd)
leaderALLspd

# Make plot
par(mfrow=(c(2,1)),oma=c(0,0,0,0))
plotleadertermGER(data= leaderALLcdu,plotleg=FALSE,mytitle="Christian Democrats (CDU/CSU)",xlabtitle="Proportion of party leader speeches")
plotleadertermGER(data= leaderALLspd,plotleg=FALSE,mytitle="Social Democrats (SPD)",xlabtitle="Proportion of party leader speeches")


###########################################################
## Figure 2C: GERMANY (Bundestag) List MPs vs. District MPs
###########################################################

dl8cdu<-listdistrictGER(legperiod=8,data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
dl9cdu<-listdistrictGER(legperiod=9,data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
dl10cdu<-listdistrictGER(legperiod=10,data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
dl11cdu<-listdistrictGER(legperiod=11,data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"),nounif=TRUE)
dl12cdu<-listdistrictGER(legperiod=12,data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
dl13cdu<-listdistrictGER(legperiod=13,data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
dlALLcdu<-rbind(dl8cdu,dl9cdu,dl10cdu,dl11cdu,dl12cdu,dl13cdu)

dl8spd<-listdistrictGER(legperiod=8,data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
dl9spd<-listdistrictGER(legperiod=9,data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
dl10spd<-listdistrictGER(legperiod=10,data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
dl11spd<-listdistrictGER(legperiod=11,data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD",nounif=TRUE)
dl12spd<-listdistrictGER(legperiod=12,data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
dl13spd<-listdistrictGER(legperiod=13,data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
dlALLspd<-rbind(dl8spd,dl9spd,dl10spd,dl11spd,dl12spd,dl13spd)

# Make plot
par(mfrow=(c(2,1)),oma=c(0,0,0,0))
plotleadertermGER(data= dlALLcdu,plotleg=FALSE,mytitle="Christian Democrats (CDU/CSU)",xlabtitle="Proportion of district MP speeches")
plotleadertermGER(data= dlALLspd,plotleg=FALSE,mytitle="Social Democrats (SPD)",xlabtitle="Proportion of district MP speeches")


#########################
#########################
# MP-Level Analysis     #
#########################
#########################

#############################
### Table 1A: UK Count Models
#############################

modeluk1<-zelig(Term20012005 ~  partyleader+conservativesdummy,model="negbin",data=legspeechdata$ukMPdata$allMPs)
modeluk2<-zelig(Term20012005 ~  partyleader,model="negbin",data=legspeechdata$ukMPdata$conMPs)
modeluk3<-zelig(Term20012005 ~ distance + partyleader+ conservativesdummy,model="negbin",data=legspeechdata$ukMPdata$distallMPs)

# Generate nice output table
options(signif.symbols=c("***"=.01,"**"=.05,"*"=.1))
modelsUK <-mtable("Model 1"=modeluk1,"Model 2"=modeluk2,"Model 3"=modeluk3,summary.stats=c("Log-likelihood","N"))
modelsUK<-relabel(modelsUK, 
	"(Intercept)" = "Constant",
	"distance" = "Distance MP to Party Leadership",
	"conservativesdummy" = "Party: Conservatives")

modelsUK


##################################
### Table 1B: Germany Count Models
################################## 


modelger1<-zelig(Speech~ partyleader +Type+Assignments,
	model="negbin",data=legspeechdata$gerMPdata$original)
modelger2<-zelig(Speech~ almckdistance + partyleader+Type+ Assignments,
	model="negbin",data=legspeechdata$gerMPdata$bt16finaldata)
modelger3<-zelig(Speech~ almckdistance +partyleader+Type+ Assignments+Party,
	model="negbin",data=legspeechdata$gerMPdata$bt16finaldata)
modelger4<-zelig(Speech~ almckdistance + coalMPoutside +partyleader+Type+ Assignments+Party,
	model="negbin",data=legspeechdata$gerMPdata$bt16finaldata)
modelger5<-zelig(Speech~ almckdistance + coalMPoutside +partyleader+Type+ Assignments+Party
	,model="negbin",data=legspeechdata$gerMPdata$bt16finaldata[legspeechdata$gerMPdata$bt16finaldata$Party=="CDU/CSU"|legspeechdata$gerMPdata$bt16finaldata$Party=="SPD",])


# Generate nice output tables
options(signif.symbols=c("***"=.01,"**"=.05,"*"=.1))
modelsGER<-mtable("Model 1"=modelger1,"Model 2"=modelger2,"Model 3"=modelger3,"Model 4"=modelger4,"Model 5"=modelger5,summary.stats=c("Log-likelihood","N"))

modelsGER <-relabel(modelsGER, 
	"(Intercept)" = "Constant",
	"almckdistance" = "Distance MP to Party Leadership (AM rescaled/leader self)",
	"almckdistancePARTYPOS" = "Distance MP to Party Leadership (AM rescaled/party pos)",
	"partyleader"="Party Leader",
	"Assignments"="Committee Assignments",
	"Type: List/District"="Party List MP",
	"coalMPoutside"="MP position outside coalition pareto set")

modelsGER




#####################################
### Figure 3: Simulated Speech Counts
#####################################

# UK simulate speech counts for increasing MP-leader distance
mysimmodel<-modeluk3
distlow<-min(mysimmodel$model$distance)
disthi<-max(mysimmodel$model$distance)
myxseq<-seq(distlow,disthi,length.out=50)
distance.x<-setx(mysimmodel,partyleader=0,conservativesdummy=0,distance =myxseq)
mysim<-sim(mysimmodel,x=distance.x)
cilo<-function(x){quantile(x,0.025)}
cihi<-function(x){quantile(x,0.975)}

# UK plot
plot(x=c(distlow,disthi),ylim=c(50,350),xlim=c(0.33,5.5),type="n",xlab="Ideological Distance between MP and Party Leadership",ylab="Legislative speeches",main="UK House of Commons (2001-2005)",sub="Simulation based on model 3 (only backbenchers from Labour party)",cex.sub=0.6,xaxt="n",las=1)
axis(1,at=seq(0.5,5.5,by=0.5),cex.axis=0.75)
lines(myxseq,apply(mysim$qi$ev,2,mean),col="black",lwd=2)
lines(myxseq,apply(mysim$qi$ev,2,cilo),lty=2,col="grey20",lwd=1.5)
lines(myxseq,apply(mysim$qi$ev,2,cihi),lty=2,col="grey20",lwd=1.5)

#GER simulate speech counts for increase MP-leader distance
mysimmodel<-modelger4
distlow<-min(mysimmodel$model$almckdistance)
disthi<-max(mysimmodel$model$almckdistance)
myxseq<-seq(distlow,disthi,length.out=50)
distance.x<-setx(mysimmodel,partyleader=0,Party="SPD",almckdistance =myxseq,coalMPoutside=1)
mysim<-sim(mysimmodel,x=distance.x,n=10000)
cilo<-function(x){quantile(x,0.025)}
cihi<-function(x){quantile(x,0.975)}

#GER plot
plot(x=c(distlow,disthi),y=c(4,25),type="n",xlab="Ideological Distance between MP and Party Leadership",ylab="Legislative speeches",main="German Bundestag (2005-2009)",sub="Simulation based on model 4 (only backbenchers from Social Democratic Party outside coalition interval)",cex.sub=0.6,xaxt="n",las=1)
axis(1,at=seq(distlow,disthi,by=0.1),cex.axis=0.75)
lines(myxseq,apply(mysim$qi$ev,2,mean),col="black",lwd=2)
lines(myxseq,apply(mysim$qi$ev,2,cilo),lty=2,col="grey20",lwd=1.5)
lines(myxseq,apply(mysim$qi$ev,2,cihi),lty=2,col="grey20",lwd=1.5)

#################################
#################################
### ROBUSTNESS CHECKS         ###
### See Supporting Appendix D ###
#################################
#################################

################################################
### 1. Definition of party leadership in GERMANY
################################################


myleaders<-c(2,3,4,5,6,7,8,9,10,11,12,13)

# CDU/CSU
leader8cdu<-leaderproportionsGER(legperiod=8,leadpositions= c(2,3,4,5,6,7,8,9,10,11,12,13),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
leader9cdu<-leaderproportionsGER(legperiod=9,leadpositions= c(2,3,4,5,6,7,8,9,10,11,12,13),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
leader9acdu<-leaderproportionsGER(legperiod="9a",leadpositions= c(2,3,4,5,6,7,8,9,10,11,12,13),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
leader9bcdu<-leaderproportionsGER(legperiod="9b",leadpositions= c(2,3,4,5,6,7,8,9,10,11,12,13),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
leader10cdu<-leaderproportionsGER(legperiod=10,leadpositions= c(2,3,4,5,6,7,8,9,10,11,12,13),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
leader11cdu<-leaderproportionsGER(legperiod=11,leadpositions= c(2,3,4,5,6,7,8,9,10,11,12,13),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"),nounif=TRUE)
leader12cdu<-leaderproportionsGER(legperiod=12,leadpositions= c(2,3,4,5,6,7,8,9,10,11,12,13),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
leader13cdu<-leaderproportionsGER(legperiod=13,leadpositions= c(2,3,4,5,6,7,8,9,10,11,12,13),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty=c("CDU","CSU","CDU/CSU"))
leaderALLcdu<-rbind(leader8cdu,leader9cdu,leader10cdu,leader11cdu,leader12cdu,leader13cdu)
leaderALLcdu

# SPD
leader8spd<-leaderproportionsGER(legperiod=8,leadpositions= c(2,3,4,5,6,7,8,9,10,11,12,13),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
leader9spd<-leaderproportionsGER(legperiod=9,leadpositions= c(2,3,4,5,6,7,8,9,10,11,12,13),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
leader9aspd<-leaderproportionsGER(legperiod="9a",leadpositions= c(2,3,4,5,6,7,8,9,10,11,12,13),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
leader9bspd<-leaderproportionsGER(legperiod="9b",leadpositions= c(2,3,4,5,6,7,8,9,10,11,12,13),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
leader10spd<-leaderproportionsGER(legperiod=10,leadpositions= c(2,3,4,5,6,7,8,9,10,11,12,13),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
leader11spd<-leaderproportionsGER(legperiod=11,leadpositions= c(2,3,4,5,6,7,8,9,10,11,12,13),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD",nounif=TRUE)
leader12spd<-leaderproportionsGER(legperiod=12,leadpositions= c(2,3,4,5,6,7,8,9,10,11,12,13),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
leader13spd<-leaderproportionsGER(legperiod=13,leadpositions= c(2,3,4,5,6,7,8,9,10,11,12,13),data=legspeechdata$BundestagSpeeches,partysub=TRUE,myparty="SPD")
leaderALLspd<-rbind(leader8spd,leader9spd,leader10spd,leader11spd,leader12spd,leader13spd)
leaderALLspd



###########################################
### 2. Definition of party leadership in UK
###########################################

# Labour - only whips
out.labwhips<-leaderproportionsUK(leadpositions=2,data=legspeechdata$labourfinalwhips,speeches=legspeechdata$labspeeches)
out.labwhips

# Labour - with cabinet
out.labgov<-leaderproportionsUK(leadpositions=2,data=legspeechdata$labourfinalgov,speeches=legspeechdata$labspeeches)
out.labgov



######################################
### 3. Demand of list MPs in Germany
######################################


nboot<-1000
bootresults<-matrix(NA,nboot,2)
names(bootresults)<-c("Sim Means:List","Sim Means:District")

for (i in 1:nboot){
	bootresults[i,1]<-mean(sample(legspeechdata$GERattendance$listmps$missprop,length(legspeechdata$GERattendance$listmps$missprop),replace=TRUE))
	bootresults[i,2]<-mean(sample(legspeechdata$GERattendance$districtmps$missprop,length(legspeechdata$GERattendance$districtmps$missprop),replace=TRUE))
	}
	
diffmeans<-bootresults[,1]-bootresults[,2]
cidiffboot<-quantile(diffmeans,c(0.025,0.975))
cidiffboot
t.test(legspeechdata$GERattendance$listmps$missprop,legspeechdata$GERattendance$districtmps$missprop)	

#####################
### 4. Budget Debates
#####################

mod.ger<-zelig(speechbinary~partyleader+budgetcommittee+MP.Party,data=legspeechdata$budgetdebates$gerbudget2010,model="probit")
mod.uk<-zelig(speechbin~partyleader+treascom+labdummy+libdummy,data=legspeechdata$budgetdebates$ukbudget2011,model="probit")
options(signif.symbols=c("***"=.01,"**"=.05,"*"=.1))
mtable("Germany"=mod.ger,"United Kingdom"=mod.uk,summary.stats=c("Log-likelihood","N"),digits=2)
